==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/BinaryReadSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.BinaryReadSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Binary read settings.
 * @property compressionProperties Compression settings.
 * @property type The read setting type.
 * Expected value is 'BinaryReadSettings'.
 */
public data class BinaryReadSettingsArgs(
    public val compressionProperties: Output<Any>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.BinaryReadSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.BinaryReadSettingsArgs =
        com.pulumi.azurenative.datafactory.inputs.BinaryReadSettingsArgs.builder()
            .compressionProperties(compressionProperties?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BinaryReadSettingsArgs].
 */
@PulumiTagMarker
public class BinaryReadSettingsArgsBuilder internal constructor() {
    private var compressionProperties: Output<Any>? = null

    private var type: Output<String>? = null

    /**
     * @param value Compression settings.
     */
    @JvmName("asqmgntfdvdxaqrl")
    public suspend fun compressionProperties(`value`: Output<Any>) {
        this.compressionProperties = value
    }

    /**
     * @param value The read setting type.
     * Expected value is 'BinaryReadSettings'.
     */
    @JvmName("mafadxfthpamqxyw")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Compression settings.
     */
    @JvmName("lsjmarmhfrvjqxdg")
    public suspend fun compressionProperties(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.compressionProperties = mapped
    }

    /**
     * @param value The read setting type.
     * Expected value is 'BinaryReadSettings'.
     */
    @JvmName("eciejqgisrcuoduv")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): BinaryReadSettingsArgs = BinaryReadSettingsArgs(
        compressionProperties = compressionProperties,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/BinaryReadSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.BinaryReadSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Binary read settings.
 * @property compressionProperties Compression settings.
 * @property type The read setting type.
 * Expected value is 'BinaryReadSettings'.
 */
public data class BinaryReadSettingsArgs(
    public val compressionProperties: Output<Any>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.BinaryReadSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.BinaryReadSettingsArgs =
        com.pulumi.azurenative.datafactory.inputs.BinaryReadSettingsArgs.builder()
            .compressionProperties(compressionProperties?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BinaryReadSettingsArgs].
 */
@PulumiTagMarker
public class BinaryReadSettingsArgsBuilder internal constructor() {
    private var compressionProperties: Output<Any>? = null

    private var type: Output<String>? = null

    /**
     * @param value Compression settings.
     */
    @JvmName("eaierxmhrbcwqeuc")
    public suspend fun compressionProperties(`value`: Output<Any>) {
        this.compressionProperties = value
    }

    /**
     * @param value The read setting type.
     * Expected value is 'BinaryReadSettings'.
     */
    @JvmName("uhodtjwfpidpnqiu")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Compression settings.
     */
    @JvmName("atfhojgnugwdiodw")
    public suspend fun compressionProperties(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.compressionProperties = mapped
    }

    /**
     * @param value The read setting type.
     * Expected value is 'BinaryReadSettings'.
     */
    @JvmName("rdfuxqdwnfriksob")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): BinaryReadSettingsArgs = BinaryReadSettingsArgs(
        compressionProperties = compressionProperties,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
